CookyChat = LibStub("AceAddon-3.0"):NewAddon("CookyChat","AceConsole-3.0","AceEvent-3.0")
CookyChatHandler = CreateFrame("Frame")
-- |cffFF69B4 pink
-- |cffBF5FFF purple

local icon = LibStub("LibDBIcon-1.0", true)
local ldb = LibStub:GetLibrary("LibDataBroker-1.1")
local cookyToolTip = "|cffBF5FFFCooky|rChat\n|cffFF69B4Left-Click|r: toggle on/off.\n|cffFF69B4Right-Click|r: open settings menu."

local CookyChatLBD = ldb:NewDataObject("CookyChat", {
	label = "CookyChat",
	type = "data source",
	text = "CookyChat",
	icon = "Interface\\AddOns\\CookyChat\\Media\\icon",
})

function CookyChat:OnInitialize()
	CookyChat.db = LibStub("AceDB-3.0"):New("CookyChatDB", CookyChat.defaults, true)
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("CookyChat", self.options)
	self.Groups = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("CookyChat", "CookyChat", nil, "groups")
	self.Blacklists = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("CookyChat", "Blacklist", "CookyChat", "blacklist")
	
	icon:Register("CookyChat", CookyChatLBD, self.db.profile.icon)
	
	CookyChatHandler:RegisterEvent("CHAT_MSG_BN_WHISPER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_SAY")
	CookyChatHandler:RegisterEvent("CHAT_MSG_GUILD")
	CookyChatHandler:RegisterEvent("CHAT_MSG_OFFICER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_PARTY")
	CookyChatHandler:RegisterEvent("CHAT_MSG_PARTY_LEADER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID_LEADER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_RAID_WARNING")
	CookyChatHandler:RegisterEvent("CHAT_MSG_WHISPER")
	CookyChatHandler:RegisterEvent("CHAT_MSG_YELL")
	
	-- Not working fully
	-- CookyChatHandler:RegisterEvent("CHAT_MSG_INSTANCE")
	-- CookyChatHandler:RegisterEvent("CHAT_MSG_INSTANCE_LEADER")
	
	CookyChat:CreateGroups()
	CookyChat:CreateBlacklist()
	
	if self.db.profile.globalActive then
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon"
	else
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon_bw"
	end
end

function CookyChatLBD:OnEnter()
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint("TOPLEFT", self, "BOTTOMLEFT")
	GameTooltip:ClearLines()
	GameTooltip:AddLine(cookyToolTip, 1, 1, 1, 1)
	GameTooltip:Show()
end

function CookyChatLBD:OnClick(button)
	if button == "LeftButton" then
		print("|cffBF5FFFCooky|rChat: |cffFF69B4"..CookyChat:OnOrOff(true))
		CookyChat:UpdateDisplay()
	elseif button == "RightButton" then
		InterfaceOptionsFrame_OpenToCategory(CookyChat.Groups)
	end
end



function CookyChat:OnOrOff(toggle)
	if toggle then
		self.db.profile.globalActive = not self.db.profile.globalActive
	end

	if self.db.profile.globalActive then 
		return "On."
	else 
		return "Off." 
	end
end

function CookyChat:RefreshMMButton()
	if icon then
		icon:Refresh("CookyChat", self.db.profile.icon)
		if self.db.profile.icon.hide then
			icon:Hide("CookyChat")
		else
			icon:Show("CookyChat")
		end
	end
end

function CookyChat:UpdateDisplay()
	if self.db.profile.globalActive then
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon"
	else
		CookyChatLBD.icon = "Interface\\AddOns\\CookyChat\\Media\\icon_bw"
	end
end

-- function CookyChat:ChatCommand(input)
	-- self:GetArgs(input, 3)
	
	-- if arg2 == "maxgroups" then
		-- if arg3 then
			-- GroupControls.MAX_GROUPS = arg3
			-- print("|cffBF5FFFCooky|rChat: Maximum number of groups changed to |cffFF69B4"..arg3.."|r.")
		-- else
			-- print("|cffBF5FFFCooky|rChat: Missing number.")
		-- end
	-- elseif arg2 == "maxblacklist" then
		-- if arg3 then
			-- GroupControls.MAX_BLACKLIST = arg3
			-- print("|cffBF5FFFCooky|rChat: Maximum number of blacklists changed to |cffFF69B4"..arg3.."|r.")
		-- else
			-- print("|cffBF5FFFCooky|rChat: Missing number.")
		-- end
	-- else
		-- print("|cffBF5FFFCooky|rChat: Please input a command, <maxgroups> <maxblacklist>")
	-- end


  -- if not input or input:trim() == "" then
    -- InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
  -- else
	-- LibStub("AceConfigCmd-3.0"):HandleCommand("cooky", "CookyChat", input)
	-- LibStub("AceConfigCmd-3.0"):HandleCommand("cc", "CookyChat", input)
	-- LibStub("AceConfigCmd-3.0"):HandleCommand("cookychat", "CookyChat", input)
  -- end
-- end

function CookyChat:OnBlacklist(event, shortSource, pID)
	if self.db.profile.blacklist then
		for i = 1, #self.db.profile.blacklist do
			if string.lower(self.db.profile.blacklist[i]) == string.lower(shortSource) then
				return true
			end
		end
	end
	return false
end

-- function CookyChat:FriendNameForID(pID)
	-- for i=1, BNGetNumFriends() do
		-- local presenceID, presenceName = BNGetFriendInfo(i)
		-- if pID == presenceID then
			-- return presenceName
		-- end
	-- end
-- end

local compareMessage
local trigger
local spamBlock = false
local msgNumber = 0

function CookyChat:FindTrigger(message, event, shortSource, fullSource, pID)
	for i = 1, self.db.profile.numFilled do
		if not self.db.profile.groupCaseSensitive[i] then 
			compareMessage = string.lower(message)
			trigger = string.lower(self.db.profile.trigger[i])
		else
			compareMessage = message
			trigger = self.db.profile.trigger[i]
		end
		
		if string.find(compareMessage, trigger) and self.db.profile.globalActive and self.db.profile.groupActive[i] and not spamBlock then
			C_Timer.After(5, function() msgNumber = 0 spamBlock = false end)
			CookyChat:Reply(event, i, shortSource, fullSource, pID)
			msgNumber = msgNumber + 1
			if msgNumber == 3 then
				spamBlock = true
			end
		end
	end		
end

function CookyChat:Reply(event, num, shortSource, fullSource, pID)
	if event == "CHAT_MSG_SAY" and shortSource ~= UnitName("player") then -- If message is from say and source isn't player
		if self.db.profile.seperateChannelActivityOption then -- If seperate channel per group is active
			if self.db.profile.groupChannelActive[num][1] then -- If that particular channel is active
				SendChatMessage(self.db.profile.reply[num],"SAY")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"SAY")
		end
	elseif event == "CHAT_MSG_YELL" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][8] then
				SendChatMessage(self.db.profile.reply[num],"YELL")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"YELL")
		end
	elseif event == "CHAT_MSG_GUILD" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][6] then
				SendChatMessage(self.db.profile.reply[num],"GUILD")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"GUILD")
		end
	elseif event == "CHAT_MSG_OFFICER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][7] then
				SendChatMessage(self.db.profile.reply[num],"OFFICER")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"OFFICER")
		end
	elseif event == "CHAT_MSG_PARTY" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][4] then
				SendChatMessage(self.db.profile.reply[num],"PARTY")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		end	
	elseif event == "CHAT_MSG_PARTY_LEADER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][4] then
				SendChatMessage(self.db.profile.reply[num],"PARTY")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"PARTY")
		end	
	elseif event == "CHAT_MSG_RAID" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][5] then
				SendChatMessage(self.db.profile.reply[num],"RAID")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end	
	elseif event == "CHAT_MSG_RAID_LEADER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][5] then
				SendChatMessage(self.db.profile.reply[num],"RAID")
			end
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end	
	elseif event == "CHAT_MSG_RAID_WARNING" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][5] then
				SendChatMessage(self.db.profile.reply[num],"RAID")
				end
		else
			SendChatMessage(self.db.profile.reply[num],"RAID")
		end
	elseif event == "CHAT_MSG_WHISPER" and shortSource ~= UnitName("player") then
		if self.db.profile.seperateChannelActivityOption then
			if self.db.profile.groupChannelActive[num][2] then
				SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
			end
		else
			SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
		end
	-- elseif event == "CHAT_MSG_INSTANCE" and shortSource ~= UnitName("player") then
		-- print("|cffBF5FFFCooky|rChat: "..)
	
		-- if self.db.profile.seperateChannelActivityOption then
			-- if self.db.profile.groupChannelActive[num][2] then
				-- SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
			-- end
		-- else
			-- SendChatMessage(self.db.profile.reply[num],"WHISPER", nil, fullSource)
		-- end
	elseif event == "CHAT_MSG_BN_WHISPER" then
		if not BNIsSelf(pID) then
			if self.db.profile.seperateChannelActivityOption then
				if self.db.profile.groupChannelActive[num][3] then
					BNSendWhisper(pID,self.db.profile.reply[num])
				end
			else
				BNSendWhisper(pID,self.db.profile.reply[num])
			end
		end
	end
end

CookyChatHandler:SetScript("OnEvent", function(_,event,message,fullSource,_,_,shortSource,_,_,_,_,_,_,_,pID)
	-- if event == "CHAT_MSG_INSTANCE" then
		-- print("|cffBF5FFFCooky|rChat: .."..message)
	-- elseif event == "CHAT_MSG_INSTANCE_LEADER" then
		-- print("|cffBF5FFFCooky|rChat LEADER: .."..message)
	-- end
	
	if not CookyChat:OnBlacklist(event, shortSource) then
		CookyChat:FindTrigger(message, event, shortSource, fullSource, pID)
	end
end)